#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-3hlWMCcCsU6567NrzdRuG3
key:                  cassava-megaparsec-2.1.1-3hlWMCcCsU6567NrzdRuG3
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  9a69150d762575a43e338e61af289ba6
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-3hlWMCcCsU6567NrzdRuG3
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cassava-0.5.4.1-2g3Aqdsm0BHx7bWZYTjZE
    megaparsec-9.7.0-HRxDu6YnAVL4jvPx7zVygA
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

